==> SCFiler2-0.12.zip: SCFiler2/SCFiler2/ViewContextMenu.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using SCFiler2.FileSystem;

namespace SCFiler2 {
	/// <summary>
	/// t@Cr[ŎgReLXgj[BVOg
	/// </summary>
	public class ViewContextMenu {
		static private ViewContextMenu instance = new ViewContextMenu();
		static public ViewContextMenu Instance {
			get { return instance; }
		}

		private ContextMenu context_menu = new ContextMenu();
		private MenuItem sendto_menu = null;

		/// <summary>
		/// ACeɉReLXgj[擾
		/// </summary>
		/// <param name="item">ReLXgj[擾ACeBėpIȂ̂~ꍇnull</param>
		/// <returns>ReLXgj[</returns>
		public ContextMenu getContextMenu(FilerItem item) {
			context_menu.MenuItems.Clear();

			//gqɊ֘AÂĂ郁j[擾
			//T.B.D

			//SendTo͌Œœ̂g
			context_menu.MenuItems.Add(sendto_menu);
			return context_menu;
		}

		private ViewContextMenu() {
			sendto_menu = constructSendToContextMenu();
		}

		private MenuItem constructSendToContextMenu() {
			string sendto_folder = Environment.GetFolderPath(Environment.SpecialFolder.SendTo);
			string[] files = System.IO.Directory.GetFiles(sendto_folder);
			MenuItem sendto_items = new MenuItem("SendTo");
			foreach (string file in files) {
				MenuItem item = new MenuItem(System.IO.Path.GetFileNameWithoutExtension(file),sendToEventHandler);
				item.Tag = file;
				sendto_items.MenuItems.Add(item);
			}
			return sendto_items;
		}

		private void sendToEventHandler(Object sender, EventArgs e) {
			string target_files = "";
			MainForm main_form = MainForm.Instance;
			foreach (FilerItem item in main_form.getLastFocusedFileView().SelectedFilerItems) {
				target_files += item.Info.FullName + " ";
			}

			MenuItem menu_item = (MenuItem)sender;
			System.Diagnostics.Process.Start((string)menu_item.Tag, target_files);
		}
	}
}

==> SCFiler2-0.13.zip: SCFiler2/SCFiler2/ViewContextMenu.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using SCFiler2.FileSystem;

namespace SCFiler2 {
	/// <summary>
	/// t@Cr[ŎgReLXgj[BVOg
	/// </summary>
	public class ViewContextMenu {
		static private ViewContextMenu instance = new ViewContextMenu();
		static public ViewContextMenu Instance {
			get { return instance; }
		}

		private ContextMenu context_menu = new ContextMenu();
		private MenuItem sendto_menu = null;

		/// <summary>
		/// ACeɉReLXgj[擾
		/// </summary>
		/// <param name="item">ReLXgj[擾ACeBėpIȂ̂~ꍇnull</param>
		/// <returns>ReLXgj[</returns>
		public ContextMenu getContextMenu(FilerItem item) {
			context_menu.MenuItems.Clear();

			//gqɊ֘AÂĂ郁j[擾
			//T.B.D

			//SendTo͌Œœ̂g
			context_menu.MenuItems.Add(sendto_menu);
			return context_menu;
		}

		private ViewContextMenu() {
			sendto_menu = constructSendToContextMenu();
		}

		private MenuItem constructSendToContextMenu() {
			string sendto_folder = Environment.GetFolderPath(Environment.SpecialFolder.SendTo);
			string[] files = System.IO.Directory.GetFiles(sendto_folder);
			MenuItem sendto_items = new MenuItem("SendTo");
			foreach (string file in files) {
				MenuItem item = new MenuItem(System.IO.Path.GetFileNameWithoutExtension(file),sendToEventHandler);
				item.Tag = file;
				sendto_items.MenuItems.Add(item);
			}
			return sendto_items;
		}

		private void sendToEventHandler(Object sender, EventArgs e) {
			string target_files = "";
			MainForm main_form = MainForm.Instance;
			foreach (FilerItem item in main_form.getLastFocusedFileView().SelectedFilerItems) {
				target_files += "\"" + item.Info.FullName + "\" "; //t@C_uNIe[V}[Nň͂ċ󔒂ŘA
			}

			MenuItem menu_item = (MenuItem)sender;
			System.Diagnostics.Process.Start((string)menu_item.Tag, target_files);
		}
	}
}
